/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.transfer;

import org.opengion.fukurou.db.Transaction;

/**
 * 伝送要求に対するの実行方法を定義するインターフェースです。
 *
 * 各実装クラスでは、{@link #execute(String[], TransferConfig, Transaction)}を実装する必要があります。
 * サブクラス内部で、DB関連の処理を行う場合は、引数のTransactionオブジェクトを利用して下さい。
 * また、接続に対するCommit/Rollbackは、呼び出し元で行いますので、実行処理の中では行わないで下さい。
 *
 * @og.group 伝送システム
 *
 * @version  5.0
 * @author   Hiroki.Nakamura
 * @since    JDK1.6
 */
@FunctionalInterface
public interface TransferExec {

	/**
	 * 伝送処理を実行します。
	 *
	 * @param vals 伝送データ(配列)
	 * @param config 伝送設定オブジェクト
	 * @param tran トランザクションオブジェクト
	 */
	void execute( final String[] vals, final TransferConfig config, final Transaction tran );
}
